@@ -1,18 +1,16 @@
 name = 'lk_utils'
 
-__version__ = '1.2.11'
+__version__ = '1.3.0'
 
 __all__ = [
-    # "ast_analyser",
     "char_converter",
     "chinese_name_processor",
-    "data_converter",
+    "data_convert",
     "excel_reader",
     "excel_writer",
     "exit_ways",
     "file_combinator",
     "filesniff",
-    "html_table_converter",
     "lk_browser",
     "lk_config",
     "lk_logger",
