@@ -2,8 +2,8 @@
 @Author  : Likianta <likianta@foxmail.com>
 @Module  : _typings.py
 @Created : 2020-08-06
-@Updated : 2020-08-06
-@Version : 0.0.1
+@Updated : 2020-08-09
+@Version : 0.0.2
 @Desc    : 加速 IDE 类型推断.
 """
 from typing import *
@@ -13,5 +13,9 @@ from typing import *
 from xlsxwriter.format import Format as ExlFormat
 
 CellFormat = ExlFormat
-Row = List[Union[str, int, float, bool, None]]
-Rows = List[Row]
+CellValue = Union[str, int, float, bool, None]
+
+ColValues = RowValues = List[CellValue]
+
+RowsValues = List[RowValues]
+ColsValues = List[ColValues]
