@@ -1,6 +1,14 @@
+"""
+@Author  : Likianta <likianta@foxmail.com>
+@Module  : excel_reader.py
+@Created : 2019-00-00
+@Updated : 2020-08-09
+@Version : 1.2.17
+@Desc    :
+"""
 import xlrd
 
-from .lk_logger import lk
+from ._typings import *
 
 
 """
@@ -73,6 +81,7 @@ from .lk_logger import lk
     # 切换到第二个 sheet
     reader.activate_sheet(1)
     # 注意: 如果要切换到的 sheet 不存在, 会报错.
+    
 """
 
 
@@ -82,31 +91,23 @@ class ColIndexLocator:
     def __init__(self, header):
         """
         NOTE: 特别注意, 我们把 header_row 中的所有对象都转换成 str 类型了. 也就
-        是如果参数 header 是 ['A', 2019, False], 则 self._header 是 ['A',
-        '2019', 'False'].
+         是如果参数 header 是 ['A', 2019, False], 则 self._header 是 ['A',
+         '2019', 'False'].
         之所以这样做, 是有原因的, 见 self.find_colx() 注释.
         """
         self._header = tuple(str(x).lower() for x in header)
     
-    def find_colx(self, *query, ignore_error=False):
+    def find_colx(self, *query: str, ignore_error=False) -> int:
         """
-        NOTE: *query 仅限 str 元素.
-            这样做的目的是避免 int 元素的二义性.
+        NOTE: query 仅限 [str] 元素. 这样做的目的是避免 int 元素的二义性.
         """
-        for i in query:
-            i = str(i).lower()
+        for i in (str(x).lower() for x in query):
             if i in self._header:
                 return self._header.index(i)
             elif ignore_error:
                 return -1
-            
-        lk.logt(
-            '[ColIndexLocator][E0109]',
-            'query field not fount in the header',
-            f'query: {query}',
-            f'header: {self._header}'
-        )
-        raise ValueError
+        raise ValueError('Query field not found in the header',
+                         f'query: {query}', f'header: {self._header}')
 
 
 class ExcelReader(ColIndexLocator):
@@ -114,52 +115,35 @@ class ExcelReader(ColIndexLocator):
     book = None
     sheet = None
     header = None
-    
+
     # noinspection PyMissingConstructor
-    def __init__(self, path, sheetx=0, formatting_info=False):
+    def __init__(self, path: str, sheetx=0, formatting_info=False):
         """
-        ARGS:
-            path: 传入要读取的文件的路径.
-            sheetx: int. 选择要激活的 sheet. 默认读取第一个 sheet (sheetx=0), 最
-                大不超过该 excel 的 sheet 总数. 您也可以通过 self.activate_sheet
-                (sheetx) 来切换要读取的 sheet.
-            formatting_info: bool. 是否保留源表格样式. 例如单元格的批注, 背景色,
-                前景色等.
-                注: 只有 ".xls" 支持保留源表格样式, 如果对".xlsx" 使用会直接报错.
-                参考: http://www.bubuko.com/infodetail-2547924.html
+        :param path: 传入要读取的文件的路径.
+        :param sheetx: int. 选择要激活的 sheet. 默认读取第一个 sheet (sheetx=0),
+         最大不超过该 excel 的 sheet 总数. 您也可以通过 self.activate_sheet
+         (sheetx) 来切换要读取的 sheet.
+        :param formatting_info: bool. 是否保留源表格样式. 例如单元格的批注, 背景
+         色, 前景色等.
+            注: 只有 ".xls" 支持保留源表格样式, 如果对".xlsx" 使用会直接报错.
+            参考: http://www.bubuko.com/infodetail-2547924.html
         """
         self.filepath = path
         if '.xlsx' in path:
-            # 当要打开的文件为 ".xlsx" 格式时, 强制 formatting_info 参数为 False
+            # 当要打开的文件为 ".xlsx" 格式时, 强制 formatting_info 参数为 False.
             # 参考: http://www.bubuko.com/infodetail-2547924.html
             formatting_info = False
-        
-        self.book = xlrd.open_workbook(
-            path, formatting_info=formatting_info
-        )
-        """
-        NOTE: ExcelReader 的实例化方法只能够一次性读取 Excel 到内存中. 如果您的
-        表格非常大, 那么在此过程中会有明显卡顿.
-        本类并没有提供缓存式读取方案. 如果您需要, 请这样做:
-            # 新建一个子类继承于 ExcelReader
-            class MyExcelReader(ExcelReader):
-            
-                def __init__(self, path, sheetx=0, on_demond=True,
-                    formatting_info=False):
-                    ...
-                    
-                    self.book = xlrd.open_workbook(
-                        path, formatting_info=formatting_info,
-                        on_demond=on_demond
-                    )
-                    ...
-                
-                # 并注意在结束使用时, 关闭 reader
-                def close():
-                    self.book.release_resource()
-        """
+        # NOTE: ExcelReader 的实例化方法只能够一次性读取 Excel 到内存中. 如果您
+        #  的表格非常大, 那么在此过程中会有明显卡顿.
+        self.book = xlrd.open_workbook(path, formatting_info=formatting_info)
         self.activate_sheet(sheetx)
     
+    def __enter__(self):
+        return self
+    
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        del self.book, self.sheet
+    
     def activate_sheet(self, sheetx: int):
         """
         activate a sheet by sheetx.
@@ -172,23 +156,23 @@ class ExcelReader(ColIndexLocator):
         else:
             self.header = None
             self._header = None
+
+    # --------------------------------------------------------------------------
     
-    # ------------------------------------------------
-    
-    def get_num_of_sheets(self):
+    def get_num_of_sheets(self) -> int:
         return self.book.nsheets
     
-    def get_name_of_sheets(self):
+    def get_name_of_sheets(self) -> List[str]:
         return self.book.sheet_names()
     
-    def get_num_of_rows(self):
+    def get_num_of_rows(self) -> int:
         return self.sheet.nrows
     
-    def get_num_of_cols(self):
+    def get_num_of_cols(self) -> int:
         return self.sheet.ncols
 
-    # ------------------------------------------------
-    
+    # --------------------------------------------------------------------------
+
     def get_header(self) -> list:
         return self.header
     
@@ -202,38 +186,38 @@ class ExcelReader(ColIndexLocator):
         else:
             return self.book.sheet_by_index(sheetx)
     
-    def get_filepath(self):
+    def get_filepath(self) -> str:
         return self.filepath
-    
-    # ------------------------------------------------
+
+    # --------------------------------------------------------------------------
 
     # noinspection PyUnboundLocalVariable
     @staticmethod
-    def _betterint(v):
+    def _betterint(v: Any) -> CellValue:
         """
         在 excel 中, 所有数字皆以浮点储存. 但考虑到个人需求, 我需要将一些整数在
-        python 中以 int 表示. 我将它上升为一个重要的决策. 尽管它可能带来一些负面
-        影响 (例如在上下文环境均是浮点数时).
+         python 中以 int 表示. 我将它上升为一个重要的决策. 尽管它可能带来一些负
+         面影响 (例如在上下文环境均是浮点数时).
         """
         if isinstance(v, float) and v == (x := int(v)):
             return x
         else:
             return v
     
-    def cell_value(self, x, y):
+    def cell_value(self, x, y) -> CellValue:
         v = self.sheet.cell(x, y).value
         return self._betterint(v)
     
-    def row_values(self, rowx: int) -> list:
+    def row_values(self, rowx: int) -> RowValues:
         return [
             self._betterint(x)
             for x in self.sheet.row_values(rowx)
         ]
     
-    def row_dict(self, rowx: int) -> dict:
+    def row_dict(self, rowx: int) -> Dict[Union[str, int], CellValue]:
         return dict(zip(self.header, self.row_values(rowx)))
     
-    def col_values(self, query, offset=0):
+    def col_values(self, query, offset=0) -> Union[ColValues, None]:
         if not isinstance(query, int):
             # str, list, tuple
             if isinstance(query, (str, bool, float)):
@@ -248,7 +232,8 @@ class ExcelReader(ColIndexLocator):
             for x in self.sheet.col_values(colx)[offset:]
         ]
 
-    # ------------------------------------------------ iterations
+    # --------------------------------------------------------------------------
+    # Iterations
 
     def get_range(self, offset=0):
         return range(offset, self.sheet.nrows)
@@ -267,18 +252,20 @@ class ExcelReader(ColIndexLocator):
         else:
             return zip(range(offset, self.get_num_of_rows()),
                        *(self.col_values(x, offset) for x in cols))
-    
+
+    # noinspection PyArgumentList
     def walk_rows(self, offset=0, fmt='list'):
         """
-        fmt: 'list' | 'dict'
+        fmt: 'list'/'dict'
         """
         assert fmt in ('list', 'dict')
         handle = self.row_values if fmt == 'list' else self.row_dict
         return (handle(rowx) for rowx in range(offset, self.sheet.nrows))
 
+    # noinspection PyArgumentList
     def enum_rows(self, offset=1, fmt='list'):
         """
-        fmt: 'list' | 'dict'
+        fmt: 'list'/'dict'
         """
         assert fmt in ('list', 'dict')
         handle = self.row_values if fmt == 'list' else self.row_dict
