@@ -1,12 +1,19 @@
+"""
+@Author  : Likianta <likianta@foxmail.com>
+@Module  : exit_ways.py
+@Created : 2019-05-29
+@Updated : 2020-08-09
+@Version : 1.0.7
+@Desc    :
+"""
 from time import sleep
 from sys import exit
 
 
 def main(msg='', sleepsecs=0):
     """
-    ARGS:
-        msg
-        sleepsecs: 0 表示按任意键退出; 大于 0 表示 n 秒后自动关闭
+    :param msg
+    :param sleepsecs: 0 表示按任意键退出; 大于 0 表示 n 秒后自动关闭
     """
     if msg:
         if isinstance(msg, str):
