@@ -1,10 +1,10 @@
 """
 @Author  : Likianta <likianta@foxmail.com>
-@Module  : excel_writer.py
+@Module  : lk_logger.py
 @Created : 2018-00-00
 @Updated : 2020-08-05
-@Version : 2.2.4
-@Desc    : ExcelWriter is a post-packing implementation based on XlsxWriter.
+@Version : 3.5.15
+@Desc    :
 
 Abbreviations:
     curr: current
@@ -39,7 +39,7 @@ Features:
     4. 源码行的参数复杂的情况, 也能正确显示
         code: lk.loga(A, B[C:D], E if F else G, "hello-{}".format('ni\'hao'))
         print: app.py:12  >>  <module>  >>  A = 'aa'; B[C:D] = 'bb'; E if F else
-            G = 'ee'; "hello-ni'hao"
+         G = 'ee'; "hello-ni'hao"
     5. 此外, 利用 lk.log 的 h 关键字可以打印调用者的调用者所在位置
         code: lk.loga('hello', h='parent')
         print: app.py: 23  >>  parent()  >>  'hello'
@@ -54,8 +54,8 @@ from ast import iter_child_nodes, parse as ast_parse
 from inspect import stack
 from os.path import abspath, split as ossplit
 from time import time
-from typing import *
 
+from ._typings import *
 from .time_utils import simple_timestamp
 
 """
@@ -95,20 +95,17 @@ class CallerFinder:
         return h if isinstance(h, int) \
             else self.hierarchy.get(h, self.SELF_HIERARCHY)
     
-    # ------------------------------------------------
-    
     # noinspection PyProtectedMember
     def find_caller_frame(self, hierarchy):
-        """
-        DEL: no usage.
-        """
+        """ NOTE: No usage. """
         hierarchy = self.interpret_hierarchy(hierarchy)
+        # noinspection PyUnresolvedReferences,PyUnresolvedReferences
         return sys._getframe(hierarchy)
     
     @staticmethod
     def find_caller_by_frame(frame):
         """
-        DEL: no usage.
+        NOTE: No usage.
         ARGS:
             frame: e.g.
                 last_frame = <frame at 0x0000021C15C8E9F8, file
@@ -119,7 +116,7 @@ class CallerFinder:
                         (you can see that in the source of last_frame.f_code)
         REF:
             https://stackoverflow.com/questions/2203424/python-how-to-retrieve
-            -class-information-from-a-frame-object
+             -class-information-from-a-frame-object
         """
         filepath = frame.f_code.co_filename.replace('\\', '/')
         lineno = frame.f_lineno
@@ -127,8 +124,7 @@ class CallerFinder:
         return filepath, lineno, function
     
     def find_caller_by_hierarchy(self, hierarchy):
-        """
-        find the source caller related to the target hierarchy.
+        """ find the source caller related to the target hierarchy.
         
         caller frame hierarchy:
             | caller                     | hierarchy |
@@ -168,7 +164,7 @@ class CallerFinder:
         return filepath, lineno, function, srcln
 
 
-# ------------------------------------------------
+# ------------------------------------------------------------------------------
 
 class PathManager:
     
@@ -247,7 +243,7 @@ class MsgRecorder:
             1. 不显示 DEBUG 级别和 TEMPRINT 的详细信息 (即便 show_details=True).
             2. 在输出时排下序, 让相同标签的出现在一起.
         """
-        ignore = re.compile(r'\[TEMPRINT\]|\[D\d\d\d\d\]')
+        ignore = re.compile(r'\[TEMPRINT]|\[D\d\d\d\d]')
         
         msg_container = []
         
@@ -306,7 +302,7 @@ script filename is {ossplit(launch_path)[1]}.
             f.write('\n'.join(self.log_messages))
 
 
-# ------------------------------------------------
+# ------------------------------------------------------------------------------
 
 class AstAnalyser:
     
@@ -326,12 +322,11 @@ class AstAnalyser:
             r'|\) *$')
     
     def mask_text(self, text: str):
-        """
-        对文本中出现的汉字等双字节字符进行 "掩码" 处理.
+        """ 对文本中出现的汉字等双字节字符进行 "掩码" 处理.
         一个有意思的现象, 当 text 中含有汉字等非西文字符时, 会导致 ast 在解析时
-        的 col_offset 计算错误. 该问题在 https://bugs.python.org/issue21295 中有
-        所体现, 并得到了一些解释:
-            ...col_offset 是生成节点的第一个 token 的 utf-8 字节偏移.
+         的 col_offset 计算错误. 该问题在 https://bugs.python.org/issue21295 中
+         有所体现, 并得到了一些解释:
+            "...col_offset 是生成节点的第一个 token 的 utf-8 字节偏移."
         由于一个汉字占用两个字节, 就产生了 col_offset 偏移的问题.
         为了解决它, 我们需要将汉字转换成一个伪造的字母表示. 例如:
             `lk.loga('你好', '不客气')` -> `lk.loga('xx', 'xxx')`
@@ -359,7 +354,7 @@ class AstAnalyser:
             return None
         
         # 利用 ast 对源码行 (fake_text) 中的各元素 "断句", ast 返回断句处的下标,
-        # 我们根据这些下标来分割 fake_text, 从而获取到各个独立的 "元素".
+        #  我们根据这些下标来分割 fake_text, 从而获取到各个独立的 "元素".
         # 根据测试, 第三层的遍历才是我们想要的正文.
         for a in iter_child_nodes(root):  # 1st layer: _ast.Expr (pass break)
             for b in iter_child_nodes(a):  # 2nd layer: _ast.Call (pass break)
@@ -414,18 +409,19 @@ class AstAnalyser:
             return s
 
 
-# ------------------------------------------------
+# ------------------------------------------------------------------------------
 
 class LKLogger:
     """
-    注: 本类中的所有 h = 'self' 均指向 log 函数的直接调用者 (direct caller).
+    注:
+        本类中的所有 h = 'self' 均指向 log 函数的直接调用者 (direct caller).
         'parent' 均指向直接调用者的调用者, 'grand_parent' 是直接调用者的调用者的
-        调用者, 以此类推.
+         调用者, 以此类推.
         例如, 外部函数 fx() 调用了 LKLogger.log(), 则 fx() 是直接调用者.
         例如, 外部函数 fx() 调用了 LKLogger.over(), 而 over() 调用了
-        LKLogger.log(), 则 over() 是直接调用者, fx() 是间接调用者. (因此你可以看
-        到, 为了让指向到达外部函数 fx(), over() 函数中特意将层级参数上调为
-        'parent' 了)
+         LKLogger.log(), 则 over() 是直接调用者, fx() 是间接调用者. (因此你可以
+         看到, 为了让指向到达外部函数 fx(), over() 函数中特意将层级参数上调为
+         'parent' 了)
     """
     terminal = None  # None means terminal to console.
     
@@ -434,9 +430,9 @@ class LKLogger:
     
     direct_caller = None
     _self = 'self'  # direct caller hierarchy. 绝大多数情况下, 此值是固定不变的
-    # (始终为 'self'); 少数情况下, 例如开发者想要特意将 direct caller 指向其他调
-    # 用者, 则可以操作此变量. 目前操作此变量的函数只有 LKLogger 内部的方法:
-    # self.over(), self.dump_log() and self.print_important_msg().
+    #  (始终为 'self'); 少数情况下, 例如开发者想要特意将 direct caller 指向其他
+    #  调用者, 则可以操作此变量. 目前操作此变量的函数只有 LKLogger 内部的方法:
+    #       self.over(), self.dump_log() and self.print_important_msg().
     
     _start_time = 0
     _end_time = 0
@@ -488,7 +484,7 @@ class LKLogger:
         """
         self.log_style.update(style)
     
-    # ------------------------------------------------
+    # --------------------------------------------------------------------------
     
     def _base_print(self, *msg, **kwargs):
         """
@@ -532,22 +528,22 @@ class LKLogger:
         print(prefix, end='')
         """
         注意这里我们把 print 的 end 参数设为空字符串, 而由 prtend 控制是否在末尾
-        加空格. 这样做的目的是, 在 MsgRecorder 记录的时候, 也能记录到这个
-        prtend; 否则就会在 dump 的时候发现对齐不是很美观 (特别是涉及到 log*x,
-        logd, logt, logdt 的对齐的时候).
+         加空格. 这样做的目的是, 在 MsgRecorder 记录的时候, 也能记录到这个
+         prtend; 否则就会在 dump 的时候发现对齐不是很美观 (特别是涉及到 log*x,
+         logd, logt, logdt 的对齐的时候).
         """
         
         # strip r-char
         # msg = (i.replace('\r', '') for i in msg)  # 去除 \\r 的影响
         # 注: 去除 \\r 的方法暂时不用. 因为它会引起 self.recorder.record() 记录
-        # 失败的问题. 原因尚在调查中.
+        #  失败的问题. 原因尚在调查中.
         
         # print it
         print(msg)
         self.recorder.record(prefix + msg, tag=tag)
         return msg
     
-    # ------------------------------------------------
+    # --------------------------------------------------------------------------
     
     def log(self, *data, h='self'):
         """
@@ -622,7 +618,7 @@ class LKLogger:
             print(f'\t{msg}')
         return msg_list
     
-    # ------------------------------------------------
+    # --------------------------------------------------------------------------
     
     def logx(self, *data, interval=1, h='self'):
         """
@@ -656,7 +652,7 @@ class LKLogger:
             msg = self._organize_messages(data, 'logtx', h)
             return self._base_print(*msg, tag=tag, cnt=cnt)
     
-    # ------------------------------------------------
+    # --------------------------------------------------------------------------
     
     def logdt(self, tag, *data, style='-', length=64, h='self'):
         """
@@ -671,7 +667,8 @@ class LKLogger:
             return self._base_print(*msg, tag=tag, divide_line=style * length,
                                     cnt=cnt)
     
-    # ------------------------------------------------ counter
+    # --------------------------------------------------------------------------
+    # Counter
     
     counter = _denominator = 0
     
@@ -756,7 +753,8 @@ class LKLogger:
         
         self._self = 'self'  # reset
     
-    # ------------------------------------------------ log afterwards
+    # --------------------------------------------------------------------------
+    # After things
     
     def print_important_msg(self, show_details=True, output='console'):
         self._self = 'parent'  # prompt
@@ -790,7 +788,7 @@ class LKLogger:
         self._self = 'parent'  # prompt
         self.log(f'log dumped at "{output}"', h='parent')
         self._self = 'self'  # reset
-
+    
     # --------------------------------------------------------------------------
     # Source Map
     
@@ -843,11 +841,9 @@ class LKLogger:
             
             if var_names is not None:
                 if caller in ('logt', 'logtx', 'logdt', 'logdtx'):
-                    """
-                    这些 caller 的原型都是 logt.
-                    logt 有个特殊的地方在于, 它的第一个参数是 tag. 我们必须把它
-                    剔除.
-                    """
+                    # 这些 caller 的原型都是 logt.
+                    # logt 有个特殊的地方在于, 它的第一个参数是 tag. 我们必须把
+                    #  它剔除.
                     var_names.pop(0)
             
             node = self.code_tracker.setdefault(filepath, {})
@@ -861,17 +857,17 @@ class LKLogger:
         
         IN: source_code_line (str): e.g. 'lk.loga(a, b, c, "hello")  # comment'
         OT: list|None. e.g. ['a', 'b', 'c', '']
-                1. in this example, the 4th parameter has no variant name, so we
-                would pass it as an empty string instead (both f-string is
-                treated as this)
-                2. _get_var_names() can auto strip interferences like comments,
-                external logger wrapper (`lk.log*()`), etc.
-                3. if the source code line contains break lines,
-                _get_var_names() **cannot handle it**. we have to return a bad
-                result (-> None)
+            1. in this example, the 4th parameter has no variant name, so we
+               would pass it as an empty string instead (both f-string is
+               treated as this)
+            2. _get_var_names() can auto strip interferences like comments,
+               external logger wrapper (`lk.log*()`), etc.
+            3. if the source code line contains break lines,
+               _get_var_names() **cannot handle it**. we have to return a bad
+               result (-> None)
                 
         NOTE: this method will slow down the process, please use it as less as
-        possible.
+         possible.
         """
         if not raw_line.startswith('lk.log'):
             if x := re.compile(r'lk\.log.+').findall(raw_line):
